@@ -1,4 +1,4 @@
-class Transparency(object):
+class Transparency:
     video_alpha = 'video_alpha'
     video_is_blank = 'video_is_blank'
     not_transparent = 'not_transparent'
