@@ -1,3 +1,3 @@
-class StreamType(object):
+class StreamType:
     live = 'live'
     event = 'event'
